@@ -9,7 +9,7 @@ use base qw(CHI::Test::Class);
 {
 
     package CHI::t::Subclass::Driver::HasUnsupported;
-    use Moose;
+    use Mouse;
     extends 'CHI::Driver::Memory';
     __PACKAGE__->declare_unsupported_methods(qw(get_namespaces));
     __PACKAGE__->meta->make_immutable;
